#
# spec file for package httpie
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           httpie
Version:        0.9.8
Release:        1.2
Summary:        A CLI, cURL-like tool for humans
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://httpie.org/
Source:         https://files.pythonhosted.org/packages/source/h/httpie/httpie-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  python-setuptools
Requires:       python-Pygments >= 1.5
Requires:       python-curses
Requires:       python-requests >= 2.0.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%else
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%endif

%description
HTTPie is a **command line HTTP client**. Its goal is to make CLI interaction
with web services as **human-friendly** as possible. It provides a
simple ``http`` command that allows for sending arbitrary HTTP requests using a
simple and natural syntax, and displays colorized responses. HTTPie can be used
for **testing, debugging**, and generally **interacting** with HTTP servers.

%prep
%setup -q

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc LICENSE README.rst
%{_bindir}/http
%{python_sitelib}/*

%changelog
* Thu Aug 10 2017 mardnh@gmx.de
- Fix Url
- Update to version 0.9.8
  * Extended auth plugin API.
  * Added exit status code 7 for plugin errors.
  * Added support for curses-less Python installations.
  * Fixed REQUEST_ITEM arg incorrectly being reported as required.
  * Improved CTRL-C interrupt handling.
  * Added the standard exit status code 130 for keyboard interrupts.
- Update to version 0.9.5
  * Added Python 3 as a dependency for Homebrew installations to ensure some of
    the newer HTTP features work out of the box for macOS users (starting with
    HTTPie 0.9.4.).
  * Added the ability to unset a request header with Header:, and send an empty
    value with Header;.
  * Added --default-scheme <URL_SCHEME> to enable things like $ alias https=
    'http --default-scheme=https.
  * Added -I as a shortcut for --ignore-stdin.
  * Added fish shell completion (located in extras/httpie-completion.fish in
    the Github repo).
  * Updated requests to 2.10.0 so that SOCKS support can be added via pip
    install requests[socks].
  * Changed the default JSON Accept header from application/json to application
    /json, */*.
  * Changed the pre-processing of request HTTP headers so that any leading and
    trailing whitespace is removed.
- Update to version 0.9.4
  * Added Content-Type of files uploaded in multipart/form-data requests
  * Added --ssl=<PROTOCOL> to specify the desired SSL/TLS protocol version to
    use for HTTPS requests.
  * Added JSON detection with --json, -j to work around incorrect Content-Type
  * Added --all to show intermediate responses such as redirects (with --follow
    )
  * Added --history-print, -P WHAT to specify formatting of intermediate
    responses
  * Added --max-redirects=N (default 30)
  * Added -A as short name for --auth-type
  * Added -F as short name for --follow
  * Removed the implicit_content_type config option (use "default_options":
    ["--form"] instead)
  * Redirected stdout doesn't trigger an error anymore when --output FILE is
    set
  * Changed the default --style back to solarized for better support of light
    and dark terminals
  * Improved --debug output
  * Fixed --session when used with --download
  * Fixed --download to trim too long filenames before saving the file
  * Fixed the handling of Content-Type with multiple +subtype parts
  * Removed the XML formatter as the implementation suffered from multiple
    issues
- Update to version 0.9.3
  * Changed the default color --style from solarized to monokai
  * Added basic Bash autocomplete support (need to be installed manually)
  * Added request details to connection error messages
  * Fixed 'requests.packages.urllib3' has no attribute 'disable_warnings'
    errors that occurred in some installations
  * Fixed colors and formatting on Windows
  * Fixed --auth prompt on Windows
* Fri Sep 25 2015 robert.munteanu@gmail.com
- Add requirement for python-curses
* Mon Jul 20 2015 aloisio@gmx.com
- Fixed SLE11 build
* Tue May 19 2015 prusnak@opensuse.org
- updated to 0.9.2
* Sun Jun 15 2014 prusnak@opensuse.org
- created package (version 0.8.0)
